@@ -86,7 +86,7 @@
 #define KWAYLANDCLIENT_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KWAYLANDCLIENT_NO_DEPRECATED
-#  define KWAYLANDCLIENT_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55100
+#  define KWAYLANDCLIENT_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55200
 #endif
 #ifdef KWAYLANDCLIENT_NO_DEPRECATED_WARNINGS
 #  define KWAYLANDCLIENT_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KWAYLANDCLIENT_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KWAYLANDCLIENT_DEPRECATED_WARNINGS_SINCE KWAYLANDCLIENT_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KWAYLANDCLIENT_DEPRECATED_WARNINGS_SINCE 0x55100
+#    define KWAYLANDCLIENT_DEPRECATED_WARNINGS_SINCE 0x55200
 #  endif
 #endif
 
@@ -139,8 +139,21 @@
 #else
 #  define KWAYLANDCLIENT_DEPRECATED_VERSION_5_73(text)
 #endif
+
+#if KWAYLANDCLIENT_DEPRECATED_WARNINGS_SINCE >= 0x55200
+#  define KWAYLANDCLIENT_DEPRECATED_VERSION_5_82(text) KWAYLANDCLIENT_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KWAYLANDCLIENT_DEPRECATED_VERSION_5_82(text)
+#endif
 #define KWAYLANDCLIENT_DEPRECATED_VERSION_5(minor, text)      KWAYLANDCLIENT_DEPRECATED_VERSION_5_##minor(text)
 #define KWAYLANDCLIENT_DEPRECATED_VERSION(major, minor, text) KWAYLANDCLIENT_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KWAYLANDCLIENT_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KWAYLANDCLIENT_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
+#if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
+#  define KWAYLANDCLIENT_ENUMERATOR_DEPRECATED_VERSION(major, minor, text) KWAYLANDCLIENT_DEPRECATED_VERSION(major, minor, text)
+#  define KWAYLANDCLIENT_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KWAYLANDCLIENT_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
+#else
+#  define KWAYLANDCLIENT_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
+#  define KWAYLANDCLIENT_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
+#endif
 
 #endif /* KWAYLANDCLIENT_EXPORT_H */
